pygeodesy.geodsolve

Package pygeodesy :: Module geodsolve |
[frames] | no frames]

# Module geodsolve

Wrapper to invoke Karney's GeodSolve utility as an (exact) geodesic, but intended mainly for testing purposes.

Set env variable `PYGEODESY_GEODSOLVE` to the (fully qualified) path of the `GeodSolve` executable or use property GeodesicSolve.GeodSolve.

Version: 25.12.31

Classes
| GeodSolve12Tuple 12-Tuple `(lat1, lon1, azi1, lat2, lon2, azi2, s12, a12, m12, M12, M21, S12)` with angles `lat1`, `lon1`, `azi1`, `lat2`, `lon2` and `azi2` and arc `a12` all in `degrees`, initial `azi1` and final `azi2` forward azimuths in bearings, degrees from North, distance `s12` and reduced length `m12` in `meter`, area `S12` in `meter` squared and geodesic scale factors `M12` and `M21`, both `scalar`, see GeodSolve.
| _GeodesicSolveBase (INTERNAL) Base class for GeodesicSolve and GeodesicLineSolve.
| GeodesicSolve Wrapper to invoke Karney's GeodSolve as an `Exact` version of Karney's Python class Geodesic.
| GeodesicLineSolve Wrapper to invoke Karney's GeodSolve as an `Exact` version of Karney's Python class GeodesicLine.

Variables
| __all__ = `_ALL_LAZY.geodsolve`